@@ -5,11 +5,11 @@ whisker.markdownToHTML <- function( template
                         , partials = list()
                         , debug = FALSE
                       ){
-  if (!require(markdown)){
+  if (!requireNamespace("markdown", quietly = TRUE)){
     stop("This function needs the package 'markdown', which can be installed from CRAN.")
   }
   
-  if (is.null(template) || template == ""){
+  if (is.null(template) || identical(template, "")){
     return("")
   }
   
